import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
  title:
    "Privacy Policy | RankRunners - SEO, Web Design & Digital Marketing Agency",
  description:
    "Learn how RankRunners LLC collects, uses, and protects your information.",
};

export default function PrivacyPolicy() {
  const currentDate = new Date().toLocaleDateString("en-US", {
    year: "numeric",
    month: "long",
    day: "numeric",
  });

  return (
    <>
      <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Privacy Policy">
        <div>
          <section className="services__details-area">
            <div className="container">
              <div className="services__details-wrap">
                <div className="row">
                  <div className="col order-0 order-lg-2">
                    <div className="services__details-content services__details-content-two">
                      <h2 className="title">Privacy Policy</h2>
                      <p>
                        <strong>Effective Date:</strong> July 1, 2025
                        <br />
                        <strong>Last Updated:</strong> July 1, 2025
                      </p>

                      <p>
                        Thank you for choosing RankRunners LLC ("we", "us",
                        "our"). Your privacy is important to us. This Privacy
                        Policy outlines how we collect, use, protect, and
                        disclose information when you visit RankRunners.net and
                        use our services, which include SEO, digital marketing,
                        website design, and website management for business
                        clients.
                      </p>

                      <p>
                        By using our website or services, you agree to the
                        practices described in this Privacy Policy.
                      </p>

                      <div className="services__details-inner-three">
                        <h3>1. Who We Are</h3>
                        <p>
                          RankRunners LLC is a digital agency providing
                          business-to-business services that include search
                          engine optimization (SEO), digital marketing, website
                          design, and ongoing website management. Our services
                          are tailored for businesses seeking performance-driven
                          online growth.
                        </p>
                      </div>

                      <div className="services__details-inner-three">
                        <h3>2. Information We Collect</h3>
                        <p>
                          We may collect both personal and non-personal
                          information when you visit our website or engage with
                          our services.
                        </p>

                        <h4>a. Information You Provide Voluntarily</h4>
                        <ul>
                          <li>Name, email address, phone number</li>
                          <li>Company name and business information</li>
                          <li>
                            Billing and payment details (processed through
                            Paddle)
                          </li>
                          <li>
                            Project details or business goals you share via our
                            contact forms, proposals, or onboarding processes
                          </li>
                        </ul>

                        <h4>b. Information Collected Automatically</h4>
                        <p>
                          When you visit RankRunners.net, we automatically
                          collect:
                        </p>
                        <ul>
                          <li>IP address</li>
                          <li>Browser type and version</li>
                          <li>Referring/exit pages</li>
                          <li>Time zone and location data</li>
                          <li>Device type and operating system</li>
                          <li>Website usage behavior (via analytics)</li>
                        </ul>
                      </div>

                      {/* Continue with other sections */}
                      <div className="services__details-inner-three">
                        <h3>3. How We Use Your Information</h3>
                        <p>We use the information we collect to:</p>
                        <ul>
                          <li>Deliver our services and manage your projects</li>
                          <li>
                            Respond to inquiries and provide customer support
                          </li>
                          <li>
                            Send transactional and service-related
                            communications
                          </li>
                          <li>
                            Improve our website performance and user experience
                          </li>
                          <li>
                            Conduct internal analytics and service optimization
                          </li>
                          <li>
                            Process payments via our third-party provider,
                            Paddle
                          </li>
                          <li>
                            Comply with legal obligations and prevent fraud
                          </li>
                        </ul>
                      </div>

                      {/* Add remaining sections following the same pattern */}

                      <div className="services__details-inner-three">
                        <h3>13. Contact Us</h3>
                        <p>
                          If you have any questions, concerns, or requests
                          regarding this Privacy Policy or how we handle your
                          information, please contact us at:
                        </p>
                        <div className="contact__info mb-50">
                          <ul className="list-wrap">
                            <li>
                              <div className="icon">
                                <i className="flaticon-mail" />
                              </div>
                              <div className="content">
                                <h4 className="title">Email</h4>
                                <Link href="mailto:support@rankrunners.net">
                                  support@rankrunners.net
                                </Link>
                              </div>
                            </li>
                            <li>
                              <div className="icon">
                                <i className="flaticon-phone-call" />
                              </div>
                              <div className="content">
                                <h4 className="title">Phone</h4>
                                <Link href="tel:+14702604117">
                                  (470) 260-4117
                                </Link>
                              </div>
                            </li>
                          </ul>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>
        </div>
        <div className="brand-area">
          <div className="container">
            <h4 className="brand__content">
              Trusted by Numerous Companies, Worldwide
            </h4>
            <div className="swiper-container brand-active">
              <BrandActiveSlider />
            </div>
          </div>
        </div>
      </Layout>
    </>
  );
}
